
========================
Neighborhood Algorithm
========================

------------
Installation
------------

The code is available on pypi and should work on any Linux distributions, MacOSX and Windows 10.
To install it just run:

.. code:: bash

  pip install pyNA

in the console.

You can install the package from the latest github source by doing:

.. code:: bash

  pip install git+https://github.com/rbeucher/pyNA.git

------------
Dependencies
------------

The pip install should take care of the dependencies, if not you might want to
check that you have the following packages installed on your system:

- numpy >= 1.17.4
- scipy >= 1.3.2

-----------
Recommended
-----------
We recommend using Jupyter:

- jupyter

---------
Licensing
---------

pyNA is an open-source project licensed under the MiT License. See LICENSE.md for details.

------------
Contributing
------------

-------
Contact
-------

Dr Romain BEUCHER, 
The Australian National University
romain.beucher@anu.edu.au